xclim.core package
==================

Submodules
----------

xclim.core.calendar module
--------------------------

.. automodule:: xclim.core.calendar
   :members:
   :undoc-members:
   :show-inheritance:

xclim.core.cfchecks module
--------------------------

.. automodule:: xclim.core.cfchecks
   :members:
   :undoc-members:
   :show-inheritance:

xclim.core.checks module
------------------------

.. automodule:: xclim.core.checks
   :members:
   :undoc-members:
   :show-inheritance:

xclim.core.datachecks module
----------------------------

.. automodule:: xclim.core.datachecks
   :members:
   :undoc-members:
   :show-inheritance:

xclim.core.formatting module
----------------------------

.. automodule:: xclim.core.formatting
   :members:
   :undoc-members:
   :show-inheritance:

xclim.core.indicator module
---------------------------

.. automodule:: xclim.core.indicator
   :members:
   :undoc-members:
   :show-inheritance:

xclim.core.locales module
-------------------------

.. automodule:: xclim.core.locales
   :members:
   :undoc-members:
   :show-inheritance:

xclim.core.missing module
-------------------------

.. automodule:: xclim.core.missing
   :members:
   :undoc-members:
   :show-inheritance:

xclim.core.options module
-------------------------

.. automodule:: xclim.core.options
   :members:
   :undoc-members:
   :show-inheritance:

xclim.core.units module
-----------------------

.. automodule:: xclim.core.units
   :members:
   :undoc-members:
   :show-inheritance:

xclim.core.utils module
-----------------------

.. automodule:: xclim.core.utils
   :members:
   :undoc-members:
   :show-inheritance:


Module contents
---------------

.. automodule:: xclim.core
   :members:
   :undoc-members:
   :show-inheritance:
